@@ -394,7 +394,7 @@ void MaemoBarcodeWindow::imageAnalysed(QString barcodeType, QString barcodeData,
 }
 
 void MaemoBarcodeWindow::showResultsWindow(QString barcodeData) {
-    ensurePluginsLoaded();
+    //ensurePluginsLoaded(); // not needed as we call it earlier
     resultsWindow->show();
     resultsWindow->processBarcode(barcodeData);
 }
@@ -484,6 +484,23 @@ void MaemoBarcodeWindow::saveBufferImage()
 
 }
 
+void MaemoBarcodeWindow::keyPressEvent(QKeyEvent *event)
+{
+    qDebug() << "Inside MaemoBarcodeWindow keypress";
+
+    if(event->key()==32){ // look for space
+        videoWidget->refocus();
+
+        if(this->continuousScanningMode==true){
+            saveBufferImage();
+        }else{
+            this->videoWidget->startTimedScan(this->videoWidget->timedScanInterval + 2000);
+            // give it 2 more seconds of scanning time to account for the fact that focusing must also occur
+        }
+    }
+
+    event->ignore(); // let it continue to wherever it might want to go
+}
 
 //// Use text files instead, then an app can provide a text file with its DBus data when installed
 //int MainWindow::register_external_plugin(QString appname, QString dbus_command_to_call, QString RequiredBarcodeTypes){
