@@ -59,6 +59,10 @@ ResultsWindow::~ResultsWindow()
 void ResultsWindow::setPluginActions(QList<PluginAction *>plugins) {
     qDebug() << "ResultsWindow::setPluginActions(): Called.";
     this->plugins = plugins;
+    //foreach(PluginAction *p, plugins){
+    //    qDebug() << "ResultsWindow::plugin item = " << p->getName();
+    //}
+
 }
 void ResultsWindow::changeEvent(QEvent *e)
 {
@@ -74,9 +78,9 @@ void ResultsWindow::changeEvent(QEvent *e)
 
 void ResultsWindow::processBarcode(QString barcode) {
     if(barcode.length() > 40) {
-        ui->lblResults->setText(tr("Results for '%1...'").arg(barcode.left(40)));
+        ui->lblResults->setText(tr("Results for '%1...'").arg(barcode.left(40)).simplified());
     } else {
-        ui->lblResults->setText(tr("Results for '%1'").arg(barcode));
+        ui->lblResults->setText(tr("Results for '%1'").arg(barcode).simplified());
     }
 
     checkPlugins();
@@ -134,17 +138,17 @@ void PluginActionListDelegate::paint(QPainter *painter, const QStyleOptionViewIt
     if(!e->getImage().isNull()) {
         painter->drawImage(QRect(irect.left(), irect.top(), 48, 48), e->getImage());
     }
-    painter->drawText(rect, Qt::AlignTop | Qt::AlignLeft, e->getText());
+    painter->drawText(rect, Qt::AlignTop | Qt::AlignLeft, e->getText().simplified()); // does this correctly handle UTF-8 I wonder...?
 
     if(!e->getDataImage().isNull()) {
         painter->drawImage(QRect(rect.right() - 50, rect.top(), 48, 48), e->getDataImage());
     } else {
-        painter->drawText(rect, Qt::AlignTop | Qt::AlignRight, e->getDataText());
+        painter->drawText(rect, Qt::AlignTop | Qt::AlignRight, e->getDataText().simplified());
     }
     painter->setPen(option.palette.mid().color());
     font.setPointSizeF(font.pointSizeF() * 0.70);
     painter->setFont(font);
-    painter->drawText(rect, Qt::AlignBottom | Qt::AlignLeft, e->getInformativeText());
+    painter->drawText(rect, Qt::AlignBottom | Qt::AlignLeft, e->getInformativeText().simplified());
 
     painter->restore();
 }
