@@ -2,6 +2,7 @@
 #include "ui_settingswindow.h"
 #include "maemobarcodewindow.h"
 #include "videowidget.h"
+#include "barcodedetector.h"
 #include <QDebug>
 
 SettingsWindow::SettingsWindow(MaemoBarcodeWindow *parent) :
@@ -24,6 +25,7 @@ void SettingsWindow::hideEvent(QHideEvent *) {
     settings->setValue("use_autofocus", ui->chkAutofocus->isChecked());
     settings->setValue("use_full_screen", ui->chkFullScreen->isChecked());
     settings->setValue("autofocus_delay", ui->spnAutoFocusDelay->value());
+    settings->setValue("continous_scanning", ui->radioButtonContinuousScanning->isChecked());
     if(ui->chkFullScreen->isChecked()) {
         parent->showFullScreen();
     } else {
@@ -34,6 +36,15 @@ void SettingsWindow::hideEvent(QHideEvent *) {
     } else {
         parent->videoWidget->refocusTimer->stop();
     }
+
+    if (ui->radioButtonContinuousScanning->isChecked()){
+        parent->continuousScanningMode = true;
+        parent->videoWidget->setContinuousScanning(true);
+    }else{
+        parent->continuousScanningMode = false;
+        parent->videoWidget->setContinuousScanning(false);
+    }
+
 //    settings->sync(); // Not necessary to call, it is called automatically.
 }
 
@@ -43,6 +54,8 @@ void SettingsWindow::showEvent(QShowEvent *) {
     ui->chkAutofocus->setChecked(settings->value("use_autofocus", true).toBool());
     ui->chkFullScreen->setChecked(settings->value("use_full_screen", true).toBool());
     ui->spnAutoFocusDelay->setValue(settings->value("autofocus_delay", 2.0).toDouble());
+    ui->radioButtonContinuousScanning->setChecked(settings->value("continous_scanning").toBool());
+    ui->radioButtonPressToScan->setChecked(!settings->value("continous_scanning").toBool());
 }
 
 void SettingsWindow::changeEvent(QEvent *e)
@@ -66,3 +79,14 @@ void SettingsWindow::on_spnAutoFocusDelay_valueChanged(double value)
 {
     //settings->setValue("autofocus_delay", ui->spnAutoFocusDelay->value());
 }
+
+// this is done automatically for us :)
+void SettingsWindow::on_radioButtonContinuousScanning_clicked()
+{
+    //ui->radioButtonPressToScan->setChecked(false);
+}
+
+void SettingsWindow::on_radioButtonPressToScan_clicked()
+{
+    //ui->radioButtonContinuousScanning->setChecked(false);
+}
